/*  ---------------------------------------------------------------------------
    Program  :  10_RGnestedChart.sas

    For      :  MWSUG Hands On Workshop Paper# HW-05-2013
                "Building a Better Bar Chart with SAS(r) Graph Template Language
                Perry Watts, Stakana Analytics, Elkins Park, PA

    Path     :  C:\_PW\MWSUG\MW13\BarChartHOW\pgm\AtConf

    Purpose  :  Create two nested percent bar charts that use a nested
                format. 
                  
    Input    :  cards -- summary data from SASHELP.HEART.
    Output   :  10_RGnestedPCT_a.png, 10_RGnestedPCT_b.png
    ------------------------------------------------------------------------  */
   ods path work.templat(update) sashelp.tmplmst(read);
   %let gpath=C:\HOW\Watts\png;

  proc format;
     picture pctFmt low-high = '009.9%';
     picture YaxFmt low-high = '009%'; 
   run;

  /* Style Templates */
   proc template;
    define Style BigText;
     parent = styles.statistical;
     class GraphFonts                                                      
      "Fonts used in graph styles" /  
      'GraphTitleFont' = (", ",14pt,bold)
      'GraphLabelFont' = (", ",13pt,bold) 
      'GraphValueFont' = (", ",13pt);
     class graphBorderLines /
       linethickness = 2px
       contrastcolor = black;
     class graphwalls /
       linethickness = 1px
       contrastcolor = black;
   /* ONLY WAY TO MAKE TICK MARKS BLACK */
     class graphColors / 
       'gaxis' = black;
    end;
   run;

  /* FOR LEFT-SIDE GRAPH (a) */
    proc template;
     define Style CHDstyle;
      parent = BigText;
       class graphdata1 /
         contrastColor=black
         color=CXDDDDDD;    /* No CHD */
       class graphdata2 /
         contrastcolor=black
         color=CX606060;     /* With CHD */
     end;
    run;

  /* FOR RIGHT-SIDE GRAPH (b) WITH THE GENDER COLORS MUTED WITH TRANSPARENCY*/
    proc template;
     define Style GENDERstyle;
      parent = BigText;
       class graphdata1 /
         contrastColor=black
         color=CX0000FF;    /* Male - blue */
       class graphdata2 /
         contrastcolor=black
         color=CXFF0000;    /* Female - red */
     end;
    run;

  /* DATA FOR LEFT-SIDE GRAPH: */
  data TransposeCHDstatus;
    length BMI_MPDesc $15 origStat $8;
    input BMI_MPOrd BMI_MPDesc origStat No_CHD CHD;
  dataLines;
    1      Underweight    g100pct     91.1      8.9
    2      Normal         g100pct     77.6     22.4
    3      Overweight     g100pct     68.9     31.1
    4      Obese          g100pct     60.4     39.6
  run;

  /* DATA FOR RIGHT-SIDE GRAPH THAT REQUIRES TRANSPARENCY*/
  data SummaryDat4M_F_wCHD;
   length BMI_MPDesc $15;
   input BMI_MPDesc F_mp100pct M_mp100pct;
   cards;
    Underweight     0.8        0.2
    Normal         39.7       36.9
    Overweight     36.2       47.0
    Obese          23.3       15.9
   run;

  /* CONSISTENT PERCENT BAR CHART FOR LEFT-SIDE */
proc template;
    DEFINE STATGRAPH myBChart;
    dynamic TITLE;
      BEGINGRAPH;
      entrytitle halign=center TITLE;
      LAYOUT OVERLAY / 
             CYCLEATTRS=true   /* ASSIGN COLORS BY STMT ITERATION INSTEAD GROUP AFFILIATION. */
             xaxisopts=( type=discrete label="Body Mass Index Category" 
                         labelAttrs=(weight=bold)) 
             yaxisopts=( type=linear display=(line ticks tickvalues)
                         labelattrs=(weight=bold) offsetmin=0 offsetmax=0.01
                         linearopts=(viewmax=100 tickvalueformat=yaxfmt.));

          BARCHART X=BMI_MPDesc Y=No_CHD / STAT=sum NAME="No_CHD" LEGENDLABEL="No CHD" 
                                            BARWIDTH=0.75 BARLABEl=true BARLABELATTRS=(size=13pt)
                                            BARLABELFORMAT=pctfmt.;
          BARCHART X=BMI_MPDesc Y=CHD    / STAT=sum NAME="CHD" LEGENDLABEL="CHD" 
                                            BARWIDTH=0.55 BARLABEl=true BARLABELATTRS=(size=13pt)
                                            BARLABELFORMAT=pctfmt.; 
          DISCRETELEGEND "No_CHD" "CHD"  / ACROSS=1 VALIGN=top HALIGN=right 
                                           TITLEATTRS=(SIZE=13pt) VALUEATTRS=(SIZE=13pt)
                                           BORDER=false LOCATION=inside 
                                           TITLE="Chronic Heart Disease Status" ;
        ENDLAYOUT;
      ENDGRAPH;
    END;
  RUN;
 ods listing gpath="&gpath" style=CHDstyle image_dpi=300;
 ods graphics on / reset=index imageName="10_RGnestedPCT_a" antialiasmax=10000 imagefmt=png;
 proc sgrender data=work.TransposeCHDstatus template=myBChart;  
   dynamic TITLE="Midpoint: BMI  By: CHD Status  --  Nested G100PCT";
 run;

 PROC TEMPLATE;
    DEFINE STATGRAPH myBChart;
    dynamic TITLE;
      BEGINGRAPH;
      entrytitle halign=center TITLE;
      LAYOUT OVERLAY / 
          CYCLEATTRS=true  /* ASSIGN COLORS BY STMT ITERATION INSTEAD GROUP AFFILIATION. */
          xaxisopts=( type=discrete label="Body Mass Index Category" 
                      labelAttrs=(weight=bold)) 
          yaxisopts=( type=linear display=(line ticks tickvalues)
                      labelattrs=(weight=bold) offsetmin=0 offsetmax=0.01
                      gridDisplay=on gridAttrs=(color=CXA5A5A5)
                      linearopts=(tickvalueformat=yaxfmt.));
          BARCHART X=BMI_MPDesc Y=M_mp100pct / 
                      STAT=sum NAME="Males" LEGENDLABEL="Male" 
                      BARWIDTH=0.75 BARLABEL=false
                      FILLATTRS=(TRANSPARENCY=0.5);
          BARCHART X=BMI_MPDesc Y=F_mp100pct / 
                      STAT=sum NAME="Females" LEGENDLABEL="Female" 
                      BARWIDTH=0.55 BARLABEL=false 
                      FILLATTRS=(TRANSPARENCY=0.5);
          DISCRETELEGEND "Males" "Females" / 
                      TITLEATTRS=(SIZE=13PT) VALUEATTRS=(SIZE=13pt)
                      ACROSS=2 BORDER=true LOCATION=outside 
                      TITLE="Gender:" ;
        ENDLAYOUT;
      ENDGRAPH;
    END;
  RUN;
  ods listing gpath="&gpath" style=GENDERstyle image_dpi=300;
  ods graphics on / reset=index imageName="10_RGnestedPCT_B" antialiasmax=10000 imagefmt=png;
  proc sgrender data=SummaryDat4M_F_wCHD template=myBChart;  
   dynamic TITLE="Midpoint: BMI  By: Gender  --  Nested MP100PCT";
  run;
 
