/*  ---------------------------------------------------------------------------
    Program  :  1_FirstBarChart.sas

    For      :  MWSUG Hands On Workshop Paper# HW-05-2013
                "Building a Better Bar Chart with SAS(r) Graph Template Language
                Perry Watts, Stakana Analytics, Elkins Park, PA

    Purpose  :  Demonstrate that width of bars does not hold any meaning.

    Input    :  sashelp.cars -- use a subset of makes.
 
    Output   :  1_Bchart_a.png, 1_Bchart_b.png.
    ------------------------------------------------------------------------  */
   %let gpath=C:\HOW\Watts\png;
   ods path work.templat(update) sashelp.tmplmst(read);
   title1;
  /* THERE ARE 38 DIFFERENT MAKES IN SASHELP.CARS.  WANT A SUBSET OF THEM. 97 OBS IN OUTPUT.*/
   data FiveMakes(keep=Origin make type mpg_highway mpg_city MSRP weight);
     set sashelp.cars;
     if make in("Chevrolet" "Ford" "GMC" "Mazda" "Toyota");
   run;

  proc template;
     define Style bigText;
      parent = styles.statistical;
      class GraphFonts                                                      
       "Fonts used in graph styles" /  
       'GraphTitleFont' = (", ",16pt,bold)
       'GraphLabelFont' = (", ",14pt,bold) 
       'GraphValueFont' = (", ",14pt);
      class graphBorderLines /
        linethickness = 2px
        contrastcolor = black;
     end;
   run;

   proc template;
     define statgraph myBChart;
       begingraph ;
         entrytitle "Vehicle Counts from SASHELP.CARS";
         layout overlay / xaxisopts=(label="Vehicle Make")
                          yaxisopts=(label="Count"); 
            BARCHART  X=Make;
         endlayout;
       endgraph;
     end;
   run;

  /* THE ODS DESTINATION STATEMENT */
   ods listing gpath="&gpath" style=bigText image_dpi=300;

  /* THE ODS GRAPHICS STATEMENT */
   ods graphics on / reset imageName="1_Bchart_a" antialiasmax=10000 imagefmt=png;

  /* PROC SGRENDER IS WHERE THE STATGRAPH TEMPLATE MEETS INPUT DATA */
   proc sgrender data=work.fiveMakes template=myBchart;  
   run;
   quit;

   proc template;
     define statgraph myBChart;
       begingraph ;
         entrytitle "Vehicle Counts from SASHELP.CARS";
         layout overlay / xaxisopts=(label="Vehicle Make")
                          yaxisopts=(label="Count"); 
            BARCHART  X=Make / BARWIDTH=0.6;
         endlayout;
       endgraph;
     end;
   run;
   ods graphics on / reset imageName="1_Bchart_b" antialiasmax=10000 imagefmt=png;
   proc sgrender data=work.fiveMakes template=myBchart;  
   run;
   quit;

