/*  ---------------------------------------------------------------------------
    Program  :  2_FREQchartsWoptions.sas

    For      :  MWSUG Hands On Workshop Paper# HW-05-2013
                "Building a Better Bar Chart with SAS(r) Graph Template Language
                Perry Watts, Stakana Analytics, Elkins Park, PA

    Purpose  :  Add the following BARCHART and|or AXES options
                to FREQUENCY Charts:
                 ORIENT=HORIZONTAL (2_FreqChart_a.png).
                 OFFSETMIN= OFFSETMAX= axes options (2_FreqChart_b.png)
                 FILLATTRS= OUTLINEATTRS= (2_FreqChart_b.png)
                 BARLABEL= BARLABELATTRS= (2_FreqChart_b.png)
                 GROUP= NAME= DATASKIN= (2_FreqChart_c.png)
                 
    Input    :  sashelp.cars -- use a subset of makes.
    Output   :  See PNG files listed under "Purpose".
    ------------------------------------------------------------------------  */
   %let gpath=C:\HOW\Watts\png;
   ods path work.templat(update) sashelp.tmplmst(read);
   title1;
  /* THERE ARE 38 DIFFERENT MAKES IN SASHELP.CARS.  WANT A SUBSET OF THEM */
   data FiveMakes(keep=Origin make type mpg_highway mpg_city MSRP weight);
     set sashelp.cars;
     if make in("Chevrolet" "Ford" "GMC" "Mazda" "Toyota");
   run;

  proc template;
     define Style bigText;
      parent = styles.statistical;
      class GraphFonts                                                      
       "Fonts used in graph styles" /  
       'GraphTitleFont' = (", ",16pt,bold)
       'GraphLabelFont' = (", ",14pt,bold) 
       'GraphValueFont' = (", ",14pt);
      class graphBorderLines /
        linethickness = 2px
        contrastcolor = black;
     end;
   run;

  /* BasicFreqChart1 - HORIZONTAL BAR CHART */
   proc template;
     define statgraph myBChart;
       begingraph ;
         entrytitle "Vehicle Counts from SASHELP.CARS";
         layout overlay / XAXISOPTS=(label="Count")
                          YAXISOPTS=(label="Vehicle Make"); 
           BARCHART X=Make / ORIENT=horizontal;
         endlayout;
       endgraph;
     end;
   run;
   ods listing gpath="&gpath" style=bigText image_dpi=300;
   ods graphics on / reset imageName="2_FreqChart_a" antialiasmax=10000 imagefmt=png;
   proc sgrender data=work.fiveMakes template=myBchart;  
   run;
   quit;

  /* BASICFREQCHART2 - CUSTOMIZED ATTRS BAR CHART */
   proc template;
     define statgraph myBChart;
       begingraph ;
         entrytitle "Vehicle Counts from SASHELP.CARS";
         layout overlay / xaxisopts=(label="Vehicle Make")
                          yaxisopts=(label="Count" offsetMin=0); 
            BARCHART X=Make / FILLATTRS=(COLOR=CX6F7EB3)
                              OUTLINEATTRS=(COLOR=CX292561)
                              BARLABEL=true
                              BARLABELATTRS=(SIZE=14pt);
         endlayout;
       endgraph;
     end;
   run;
   ods graphics on / reset imageName="2_FreqChart_b" antialiasmax=10000 imagefmt=png;
   proc sgrender data=work.fiveMakes template=myBchart;  
   run;
   quit;

  /* BASICFREQCHART3 - NON-REPEATING GROUP BAR CHART WITH SKINS */
   proc template;
     define statgraph myBChart;
       begingraph ;
         entrytitle "Frequencies by Vehicle Origin and Make";
         layout overlay / xaxisopts=(label="Make of Vehicle");
           BARCHART X=Make / GROUP=origin NAME="oGroup"
                             DATASKIN=pressed
                             barlabel=true
                             barlabelattrs=(size=14pt); 
           DISCRETELEGEND "oGroup" / 
                             ACROSS=2 
                             TITLEATTRS=(SIZE=14pt)
                             VALUEATTRS=(SIZE=12pt)
                             BORDER=true 
                             TITLE="Origin:";
         endlayout;
       endgraph;
     end;
   run;
   ods graphics on / reset imageName="2_FreqChart_c" antialiasmax=10000 imagefmt=png;

   proc sgrender data=work.fiveMakes template=myBchart;  
   run;
   quit;

