/*  ---------------------------------------------------------------------------
    Program  :  3_SUMchart.sas

    For      :  MWSUG Hands On Workshop Paper# HW-05-2013
                "Building a Better Bar Chart with SAS(r) Graph Template Language
                Perry Watts, Stakana Analytics, Elkins Park, PA

    Purpose  :  Create a basic STAT=SUM chart that now requires a Y parameter.
                 While STAT=SUM is the default when a Y parameter is specified, 
                 it is being made explicit in the code below. 
                In this example, it is not necessary to format the Y-axis tick
                 values from inside the BARCHART statement. GTL automatically picks
                 up the DOLLAR8. format associated with the variable MSRP from
                 the input data.
 
    Input    :  sashelp.cars -- use a subset of makes.
    Output   :  3_SumChart.png
    ------------------------------------------------------------------------  */
   %let gpath=C:\HOW\Watts\png;
   ods path work.templat(update) sashelp.tmplmst(read);
   title1;
  /* THERE ARE 38 DIFFERENT MAKES IN SASHELP.CARS.  WANT A SUBSET OF THEM */
   data FiveMakes(keep=Origin make type mpg_highway mpg_city MSRP weight);
     set sashelp.cars;
     if make in("Chevrolet" "Ford" "GMC" "Mazda" "Toyota");
   run;

/* *****
   OUTPUT FROM PROC CONTENTS:
             Data Set Name        WORK.FIVEMAKES                      Observations          97
             Member Type          DATA                                Variables              7

                                         Variables in Creation Order

                        #    Variable       Type    Len    Format      Label

                        1    origin         Char     15
                        2    Make           Char     13
                        3    Type           Char      8
                        4    MSRP           Num       8    DOLLAR8.
                        5    MPG_City       Num       8                MPG (City)
                        6    MPG_Highway    Num       8                MPG (Highway)
                        7    Weight         Num       8                Weight (LBS)
***** */

  proc template;
     define Style bigText;
      parent = styles.statistical;
      class GraphFonts                                                      
       "Fonts used in graph styles" /  
       'GraphTitleFont' = (", ",16pt,bold)
       'GraphLabelFont' = (", ",14pt,bold) 
       'GraphValueFont' = (", ",14pt);
      class graphBorderLines /
        linethickness = 2px
        contrastcolor = black;
     end;
   run;

  /* BasicSumChart - Sum MSRP */
    proc template;
      define statgraph myBChart;
        begingraph ;
          entrytitle "Sum of MSRP by Vehicle Make";
          entrytitle "(MSRP = Manufacturer's Suggested Retail Price)" 
                         / textattrs=(size=12pt);
          layout overlay / xaxisopts=(label="Make of Vehicle")
                           yaxisopts=(label="SUM (MSRP)"); 
              BARCHART X=Make Y=MSRP/  STAT=sum
                                       DATASKIN=pressed
                                       FILLATTRS=(COLOR=GraphData1:color)
                                       BARLABEL=true
                                       BARLABELATTRS=(size=12pt); 
          endlayout;
        endgraph;
      end;
    run;

   ods listing gpath="&gpath" style=bigText image_dpi=300;
   ods graphics on / reset imageName="3_SumChart" antialiasmax=10000 imagefmt=png;
   proc sgrender data=work.fiveMakes template=myBchart;  
   run;
   quit;

 
