/*  ---------------------------------------------------------------------------
    Program  :  4_PCTcharts.sas

    For      :  MWSUG Hands On Workshop Paper# HW-05-2013
                "Building a Better Bar Chart with SAS(r) Graph Template Language
                Perry Watts, Stakana Analytics, Elkins Park, PA

    Purpose  :  Create a basic STAT=PCT chart with RAW data - that shows fractions
                 instead of percents.
                Correct with SUMMARY data, STAT=SUM, and the use of PICTURE
                 FORMATS.

    Input    :  sashelp.cars -- use a subset of makes. (RAW DATA)
                summaryDat4pcts -- uses Cards statement of pre-summarized data.

    Output   :  4_PctChartRawData.png, 4_PctChartSummaryData.png
    ------------------------------------------------------------------------  */
   %let gpath=C:\HOW\Watts\png;
   ods path work.templat(update) sashelp.tmplmst(read);
   title1;
  /* THERE ARE 38 DIFFERENT MAKES IN SASHELP.CARS.  WANT A SUBSET OF THEM */
   data FiveMakes(keep=Origin make type mpg_highway mpg_city MSRP weight);
     set sashelp.cars;
     if make in("Chevrolet" "Ford" "GMC" "Mazda" "Toyota");
   run;

  proc template;
     define Style bigText;
      parent = styles.statistical;
      class GraphFonts                                                      
       "Fonts used in graph styles" /  
       'GraphTitleFont' = (", ",16pt,bold)
       'GraphLabelFont' = (", ",14pt,bold) 
       'GraphValueFont' = (", ",14pt);
      class graphBorderLines /
        linethickness = 2px
        contrastcolor = black;
     end;
   run;

   /* BEFORE GRAPH WITH PROPORTIONS INSTEAD OF PERCENTS. DEFAULT Y-AXIS LABEL IS "PERCENT"*/
   proc template;
     define statgraph myBChart;
     begingraph ;
       entrytitle halign=RIGHT "Vehicle Percents from SASHELP.CARS (Raw Data)";
         layout overlay / xaxisopts=(label="Make of Vehicle"); /* NO YAXISOPTS SPECIFIED */
            barchart  X=Make / STAT=PCT
                               DATASKIN=pressed
                               FILLATTRS=(COLOR=GraphData1:color)
                               barlabel=TRUE
                               barlabelattrs=(size=14pt); 
         endlayout;
       endgraph;
     end;
   run;
   ods listing gpath="&gpath" style=bigText image_dpi=300;
   ods graphics on / reset imageName="4_PctChartRawData" antialiasmax=10000 imagefmt=png;
   proc sgrender data=work.fiveMakes template=myBchart;  
   run;
   quit;


 /* SUMMARY DATA FOR AFTER GRAPH -- CALCULATED ELSEWHERE FROM PROC FREQ */
  data SummaryDat4pcts;
     length make $13;
     input make PctVehicles;
     cards;
     Chevrolet    27.8 
     Ford         23.7 
     GMC           8.2 
     Mazda        11.3 
     Toyota       28.9 
   run;
  
  /* NOW CREATE A TRUE PERCENT BAR CHART WITH VAR PCTVEHICLES.*/  
   proc format;
     picture pctYaxFm low-high = '009%';   /* Y-axis--PCT format */
     picture pctBarLF low-high = '009.9%'; /* Bar-Label PCT format */
   run;

   proc template;
     define statgraph myBChart;
     begingraph ;
       entrytitle halign=CENTER "Vehicle Percents from SASHELP.CARS (Summary Data)";
        layout overlay / xaxisopts=(label="Make of Vehicle")
                         yaxisopts=(display=(line ticks tickvalues)
                                    linearopts=(tickvalueformat=pctYaxFm.)); 
          barchart  x=Make y=pctVehicles / STAT=SUM  /* DEFAULT */
                                           DATASKIN=pressed
                                           FILLATTRS=(COLOR=GraphData1:color)
                                           barlabel=TRUE
                                           barlabelattrs=(size=14pt)
                                           barlabelformat=pctBarLF.; 
        endlayout;
      endgraph;
     end;
   run;
   ods graphics on / reset imageName="4_PctChartSummaryData" antialiasmax=10000 imagefmt=png;
   proc sgrender data=work.SummaryDat4pcts template=myBchart;  
   run;
   quit;

 
