/*  ---------------------------------------------------------------------------
    Program  :  5_MEANchart_eBars.sas

    For      :  MWSUG Hands On Workshop Paper# HW-05-2013
                "Building a Better Bar Chart with SAS(r) Graph Template Language
                Perry Watts, Stakana Analytics, Elkins Park, PA

    Purpose  :  Insert 95% confidence bounds into the ASCENDING bar chart
                 of means.
 
    Input    :  Summary data set derived from subset of SASHELP.CARS.
                Sorted in this program.

    Output   :  5_MeanChart_eBars.png
    ------------------------------------------------------------------------  */
   ods path work.templat(update) sashelp.tmplmst(read);
   %let gpath=C:\HOW\Watts\png;

   proc template;
    define Style bigText;
      parent = styles.statistical;
      class GraphFonts                                                      
       "Fonts used in graph styles" /  
       'GraphTitleFont' = (", ",16pt,bold)
       'GraphLabelFont' = (", ",12pt,bold) 
       'GraphValueFont' = (", ",12pt);
      class graphBorderLines /
        linethickness = 2px
        contrastcolor = black;
     end;
   run;

    /* SUMMARY DATA WITH CONFIDENCE LIMITS -- CALCULATED ELSEWHERE WITH PROC SUMMARY */
 data SummaryDat4ConfLm_MPG;
   length make $13;
   input make mean_HighwayMPG L95Clm U95Clm;
 cards;
 Chevrolet   26.8519     24.6411    29.0626  
 Ford        25.7391     23.7045    27.7738  
 GMC         19.6250     18.0263    21.2237  
 Mazda       27.2727     24.9530    29.5924  
 Toyota      30.6786     27.8915    33.4656  
 run;

 proc sort data=SummaryDat4ConfLm_MPG out=summaryDatSorted_MPG;
   by mean_highwayMPG;
 run; 

 /* CONFIDENCE LIMITS ADDED WITH THE SCATTERPLOT STATEMENT */
   ods listing gpath="&gpath" style=bigText image_dpi=300;
   ods listing style=bigText image_dpi=300;
 proc template;
   define statgraph myBChart;
     begingraph;
       entrytitle "Average Highway Gas Mileage by Vehicle Make";
       entrytitle "(In Ascending Order)" / textattrs=(size=14pt);
       layout overlay / xaxisopts=(type=discrete LABEL="Make of Vehicle") 
                        yaxisopts=(type=linear LABEL="Avg Highway MPG + 95% Conf. Limits");
            BARCHART  X=make Y=mean_highwayMPG / STAT=sum
                                                 DATASKIN=pressed;
          SCATTERPLOT X=make Y=mean_highwayMPG / MARKERATTRS=(SIZE=0)
                                                 YERRORLOWER=L95clm 
                                                 YERRORUPPER=U95clm;
       endlayout;
     endgraph;
   end;
 run;
 ods listing gpath="&gpath" style=bigText image_dpi=300;
 ods graphics on / reset imageName="5_MeanChart_eBars" antialiasmax=10000 imagefmt=png;
 proc sgrender data=WORK.summaryDatSorted_MPG template=myBchart;  
 run;
 quit;

