/*  ---------------------------------------------------------------------------
    Program  :  7_MyAnswer.sas

    For      :  MWSUG Hands On Workshop Paper# HW-05-2013
                "Building a Better Bar Chart with SAS(r) Graph Template Language
                Perry Watts, Stakana Analytics, Elkins Park, PA

    Purpose  :  Create a graph with the following characteristics by using
                BasicMeansBChartWconfLim.sas as the starting point:
                 1) Add bar labels containing MEANS for Highway Miles Per Gallon.
                 2) Assign a different color to each bar (by using defaults)
                 3) Add skins to the bars.
                 3) Make the bar labels more visible by displaying Lower
                    Confidence Limits only
 
    Input    :  Summary data set derived from subset of SASHELP.CARS.
                Sorted in this program.

    Output   :  7_InstructorAnswer_V.png -- vertical bar chart
                7_InstructorAnswer_H.png -- horizontal bar chart
    ------------------------------------------------------------------------  */
   ods path work.templat(update) sashelp.tmplmst(read);
   %let gpath=C:\HOW\Watts\png;

   proc template;
    define Style bigText;
      parent = styles.statistical;
      class GraphFonts                                                      
       "Fonts used in graph styles" /  
       'GraphTitleFont' = (", ",16pt,bold)
       'GraphLabelFont' = (", ",12pt,bold) 
       'GraphValueFont' = (", ",12pt);
      class graphBorderLines /
        linethickness = 2px
        contrastcolor = black;
     end;
   run;

  proc template;
    define Style biggerText;
      parent = styles.statistical;
      class GraphFonts                                                      
       "Fonts used in graph styles" /  
       'GraphTitleFont' = (", ",16pt,bold)
       'GraphLabelFont' = (", ",14pt,bold) 
       'GraphValueFont' = (", ",14pt);
      class graphBorderLines /
        linethickness = 2px
        contrastcolor = black;
     end;
   run;

    /* SUMMARY DATA WITH CONFIDENCE LIMITS -- CALCULATED ELSEWHERE */
 data SummaryDat4ConfLm_MPG;
   length make $13;
   input make mean_HighwayMPG L95Clm U95Clm;
 cards;
 Chevrolet   26.8519     24.6411    29.0626  
 Ford        25.7391     23.7045    27.7738  
 GMC         19.6250     18.0263    21.2237  
 Mazda       27.2727     24.9530    29.5924  
 Toyota      30.6786     27.8915    33.4656  
 run;

 proc sort data=SummaryDat4ConfLm_MPG out=summaryDatSorted_MPG;
   by mean_highwayMPG;
 run; 

 /* VERTICAL BAR CHART */
 proc template;
   define statgraph myBChart;
     begingraph;
       entrytitle "Average Highway Gas Mileage by Vehicle Make";
       entrytitle "(In Ascending Order)" / textattrs=(size=14pt);
       layout overlay / xaxisopts=(type=discrete LABEL="Make of Vehicle") 
                        yaxisopts=(type=linear LABEL="Avg Highway MPG + 95CLM Half E-Bars");
            BARCHART  X=make Y=mean_highwayMPG / STAT=SUM
                                                 DATASKIN=GLOSS
                                                 BARLABEL=TRUE
                                                 BARLABELATTRS=(size=12pt)
                                                 GROUP=Make;
            BARCHART  X=make Y=mean_highwayMPG / STAT=SUM
                                                 DISPLAY=(OUTLINE)
                                                 OUTLINEATTRS=(COLOR=BLACK thickness=1px);
          SCATTERPLOT X=make Y=mean_highwayMPG / MARKERATTRS=(SIZE=0)
                                                 ERRORBARATTRS=(Color=black)
                                                 YERRORLOWER=L95clm 
                                                 YERRORUPPER=mean_highwayMPG;
       endlayout;
     endgraph;
   end;
 run;
 ods listing gpath="&gpath" style=bigText image_dpi=300;
 ods graphics on / reset imageName="7_InstructorAnswer_V" antialiasmax=10000 imagefmt=png;
 proc sgrender data=WORK.summaryDatSorted_MPG template=myBchart;  
 run;
 quit;

  /* HORIZONTAL BAR CHART */
 proc template;
   define statgraph myBChart;
     begingraph;
       entrytitle HAlign=Right "Average Highway Gas Mileage by Vehicle Make";
       entrytitle "(In Ascending Order)" / textattrs=(size=12pt);
       layout overlay / Xaxisopts=(TYPE=linear 
                                  LABEL="Average Highway MPG + 95CLM Half E-Bars")
                        Yaxisopts=(TYPE=discrete LABEL="Make of Vehicle");
          BARCHART  X=make Y=mean_highwayMPG / STAT=SUM
                                               DATASKIN=GLOSS
                                               BARLABEL=TRUE
                                               BARLABELATTRS=(size=12pt)
                                               GROUP=Make
                                               ORIENT=HORIZONTAL;
          BARCHART  X=make Y=mean_highwayMPG / STAT=SUM
                                               DISPLAY=(OUTLINE)
                                               OUTLINEATTRS=(COLOR=BLACK thickness=1px)
                                               ORIENT=HORIZONTAL;
          SCATTERPLOT X=mean_highwayMPG Y=make / MARKERATTRS=(SIZE=0)
                                                 ERRORBARATTRS=(Color=black)
                                                 XERRORLOWER=L95clm 
                                                 XERRORUPPER=mean_highwayMPG;
       endlayout;
     endgraph;
   end;
 run;
 ods listing gpath="&gpath" style=biggerText image_dpi=300;
 ods graphics on / reset imageName="7_InstructorAnswer_H" antialiasmax=10000 imagefmt=png;
 proc sgrender data=WORK.summaryDatSorted_MPG template=myBchart;  
 run;
 quit;
