/*  ---------------------------------------------------------------------------
    Program  :  8_RGclusterChart.sas

    For      :  MWSUG Hands On Workshop Paper# HW-05-2013
                "Building a Better Bar Chart with SAS(r) Graph Template Language
                Perry Watts, Stakana Analytics, Elkins Park, PA

    Path     :  C:\_PW\MWSUG\MW13\BarChartHOW\pgm\AtConf

    Purpose  :  Create a Repeating Group Bar Chart that uses the Cluster
                format. 
                  
    Input    :  cards -- summary data from SASHELP.HEART.
    Output   :  8_RGcluster.png
    ------------------------------------------------------------------------  */
   ods path work.templat(update) sashelp.tmplmst(read);
   %let gpath=C:\HOW\Watts\png;
  proc format;
     picture pctFmt low-high = '009.9%';
     picture YaxFmt low-high = '009%'; 
  run;

  /* Style Templates */
  proc template;
    define Style BigText;
     parent = styles.statistical;
     class GraphFonts                                                      
      "Fonts used in graph styles" /  
      'GraphTitleFont' = (", ",14pt,bold)
      'GraphLabelFont' = (", ",13pt,bold) 
      'GraphValueFont' = (", ",13pt);
     class graphBorderLines /
       linethickness = 2px
       contrastcolor = black;
     class graphwalls /
       linethickness = 1px
       contrastcolor = black;
   /* ONLY WAY TO MAKE TICK MARKS BLACK */
     class graphColors / 
       'gaxis' = black;
    end;
  run;
 
  proc template;
    define Style BMIstyle;
     parent = BigText;
      class graphdata1 /
        contrastColor=black
        color=cx0000FF;      /* Under Weight (blue)*/
      class graphdata2 /
        contrastcolor=black
        color=cx707070;      /* Normal Weight (gray)*/
      class graphdata3 /
        contrastColor=black
        color=cxB2182B;      /* Overweight (dark red)*/
      class graphdata4 /
        contrastcolor=black
        color=cxFF0000;      /* Obese  (bright red) */
    end;
  run;

  /* REVERSE BMI AND CHD ROLES */
  data SummaryDat_MPchd_GRPbmi;
    length BMI_GrpDesc $15 CHD_MPDesc $10;
    input CHD_MPOrd CHD_MPDesc & BMI_GrpOrd BMI_GrpDesc g100mpOrder;
  dataLines;
    0      No CHD       1         Underweight       91.1    
    0      No CHD       2         Normal            77.6    
    0      No CHD       3         Overweight        68.9    
    0      No CHD       4         Obese             60.4    
    1      CHD          1         Underweight        8.9    
    1      CHD          2         Normal            22.4    
    1      CHD          3         Overweight        31.1    
    1      CHD          4         Obese             39.6    
  run; 

  proc template;
    define statgraph myBChart;
      dynamic TITLE TITLE2;
      begingraph;
        entrytitle halign=center TITLE;
          layout overlay / xaxisopts=( type=discrete label="Chronic Heart Disease Status")
                           yaxisopts=( type=linear display=(line ticks tickvalues)
                                       labelattrs=(weight=bold) offsetmin=0
                                       linearopts=(tickvaluefitpolicy=none 
                                                   tickvalueformat=yaxfmt.));
            barchart X=CHD_MPDesc Y=g100mpOrder / 
                         STAT=sum BARLABEL=TRUE BARLABELATTRS=(size=13pt)
                         BARLABELFORMAT=pctfmt.
                         GROUP=BMI_GrpDesc name="barGroup"
                         GROUPDISPLAY=cluster
                         BARWIDTH=0.85 CLUSTERWIDTH=0.85;  /* DEFAULT SETTINGS */
            discreteLegend "barGroup"  / across=1 valign=top 
                                         halign=right titleattrs=(size=13pt)
                                         valueattrs=(size=12pt)
                                         border=false location=inside 
                                         title="Body Mass Index" ;
          endlayout;
        endgraph;
      end;
    run;
   ods listing gpath="&gpath" style=BMIstyle image_dpi=300;
   ods graphics on / reset imageName="8_RGcluster" antialiasmax=10000 imagefmt=png;
   proc sgrender data=work.SummaryDat_MPchd_GRPbmi template=myBChart;  
     dynamic TITLE="Midpoint: CHD Status  Group: BMI Category -- G100MPorder";
   run;
