/*  ---------------------------------------------------------------------------
    Program  :  9_RGstackedChart.sas

    For      :  MWSUG Hands On Workshop Paper# HW-05-2013
                "Building a Better Bar Chart with SAS(r) Graph Template Language
                Perry Watts, Stakana Analytics, Elkins Park, PA

    Path     :  C:\_PW\MWSUG\MW13\BarChartHOW\pgm\AtConf

    Purpose  :  Create percent and frequency bar charts that use a stacked
                format. 
                  
    Input    :  cards -- summary data from SASHELP.HEART.
    Output   :  9_RGstackedPCT.png, 9_RGstackedFREQ.png
    ------------------------------------------------------------------------  */
   ods path work.templat(update) sashelp.tmplmst(read);
   %let gpath=C:\HOW\Watts\png;

  proc format;
     picture pctFmt low-high = '009.9%';
     picture YaxFmt low-high = '009%'; 
   run;

  /* Style Templates */
 proc template;
    define Style BigText;
     parent = styles.statistical;
     class GraphFonts                                                      
      "Fonts used in graph styles" /  
      'GraphTitleFont' = (", ",14pt,bold)
      'GraphLabelFont' = (", ",13pt,bold) 
      'GraphValueFont' = (", ",13pt);
     class graphBorderLines /
       linethickness = 2px
       contrastcolor = black;
     class graphwalls /
       linethickness = 1px
       contrastcolor = black;
   /* ONLY WAY TO MAKE TICK MARKS BLACK */
     class graphColors / 
       'gaxis' = black;
    end;
  run;

  proc template;
     define Style CHDstyle;
      parent = BigText;
       class graphdata1 /
         contrastColor=black
         color=CXDDDDDD;    /* No CHD */
       class graphdata2 /
         contrastcolor=black
         color=CX606060;     /* With CHD */
  end;
  run;

   data SummaryDat_MPbmi_GRPchd;
    length BMI_MPDesc $15 CHD_GrpDesc $10;
    input 
 BMI_MPOrd BMI_MPDesc CHD_GrpOrd CHD_GrpDesc & MPFreq GrpFreq  g100grOrder;
  dataLines;
  1      Underweight       1      No CHD        79       72      91.1
  1      Underweight       2      CHD           79        7       8.9
  2      Normal            1      No CHD      2456     1905      77.6
  2      Normal            2      CHD         2456      551      22.4
  3      Overweight        1      No CHD      1970     1357      68.9
  3      Overweight        2      CHD         1970      613      31.1
  4      Obese             1      No CHD       694      419      60.4
  4      Obese             2      CHD          694      275      39.6
  run;

  ods listing gpath="&gpath" style=CHDstyle image_dpi=300;

  /* STACKED BAR CHART - THE DEFAULT WITH PERCENT */
    PROC TEMPLATE;
      DEFINE STATGRAPH myBChart;
      dynamic TITLE;
      begingraph;
        entrytitle halign=right TITLE;
          LAYOUT OVERLAY / XAXISOPTS=( type=discrete label="Body Mass Index Category" 
                                       labelAttrs=(weight=bold)) 
                           YAXISOPTS=( type=linear display=(line ticks tickvalues)
                                       labelattrs=(weight=bold) offsetmin=0 offsetmax=0.01
                                       linearopts=(tickvalueformat=yaxfmt.));

            BARCHART X=BMI_MPDesc Y=g100grOrder  / 
                                       STAT=sum BARLABEL=false
                                       GROUP=CHD_GrpDesc NAME="barGroup"
                                       GROUPDISPLAY=stack
                                       BARWIDTH=0.7; 
            DISCRETELEGEND "barGroup"  / ACROSS=2 TITLEATTRS=(SIZE=13pt)
                                         VALUEATTRS=(SIZE=12pt)
                                         BORDER=true LOCATION=outside 
                                         TITLE="Chronic Heart Disease Status" ;
          ENDLAYOUT;
        ENDGRAPH;
      END;
    RUN;
  ods graphics on / reset=index imageName="9_RGstackedPCT" antialiasmax=10000 imagefmt=png;
  proc sgrender data=work.SummaryDat_MPbmi_GRPchd template=myBChart;  
    dynamic TITLE="Midpoint: BMI  Group: CHD -- Stacked PERCENT G100grOrder";
  run;

  /* STACKED BAR CHART - THE DEFAULT WITH FREQUENCY */
    ods listing style=CHDstyle image_dpi=300;
    proc template;
      define statgraph myBChart;
      dynamic TITLE;
      begingraph;
        entrytitle halign=right TITLE;
          layout overlay / xaxisopts=( type=discrete label="Body Mass Index Category" 
                                       labelAttrs=(weight=bold)) 
                           yaxisopts=( type=linear label="Count (Subjects)"
                                       labelattrs=(weight=bold) offsetmin=0
                                                   linearopts=(tickvalueformat=comma5.));
            BARCHART X=BMI_MPDesc Y=GrpFreq / 
                                       STAT=sum BARLABEL=true BARLABELATTRS=(SIZE=13pt)
                                       BARLABELFORMAT=comma5.
                                       GROUP=CHD_GrpDesc NAME="barGroup"
                                       GROUPDISPLAY=stack
                                       BARWIDTH=0.7; 

            DISCRETELEGEND "barGroup"  / ACROSS=2 TITLEATTRS=(SIZE=13pt)
                                         VALUEATTRS=(SIZE=12pt)
                                         BORDER=true LOCATION=outside 
                                         TITLE="Chronic Heart Disease Status" ;
          endlayout;
        endgraph;
      end;
    run;

  ods graphics on / reset=index imageName="9_RGstackedFREQ" antialiasmax=10000 imagefmt=png;
  proc sgrender data=work.SummaryDat_MPbmi_GRPchd template=myBChart;  
     dynamic TITLE="Midpoint: BMI  Group: CHD Status -- Stacked FREQ GrpFreq";
  run;

